flask_fontawesome package — flask-fontawesome 0.1.5 documentation

# flask_fontawesome package

## flask_fontawesome

This moudle provides helpers to quickly add FontAwesome resources to your Flask app.

class `flask_fontawesome.` `Cdn`

  Bases: `object`

  `css_html`() → markupsafe.Markup
  `js_html`() → markupsafe.Markup
  `resources_html`() → markupsafe.Markup

class `flask_fontawesome.` `FontAwesome`(app: flask.app.Flask = None)

  Bases: `object`

  `init_app`(app: flask.app.Flask) → None

class `flask_fontawesome.` `StaticCdn`

  Bases: `flask_fontawesome.Cdn`

  `css_html`() → markupsafe.Markup
  `js_html`() → markupsafe.Markup

class `flask_fontawesome.` `UseFontAwesomeComCdn`

  Bases: `flask_fontawesome.Cdn`

  `css_html`() → markupsafe.Markup
  `js_html`() → markupsafe.Markup

`flask_fontawesome.` `fontawesome_css`() → markupsafe.Markup

  Returns :class`~flask.Markup` of the CSS FontAwesome resources.

`flask_fontawesome.` `fontawesome_html`() → markupsafe.Markup

  Returns `Markup` of all the requested FontAwesome resources. This can be embedded in your Jinja templates to add FontAwesome to your site.

`flask_fontawesome.` `fontawesome_js`() → markupsafe.Markup

  Returns `Markup` of the JS FontAwesome resources.